Here is a nested unordered list:

- Here is an item
- Another item
    - Hey
    - What the heck
        - Woah *so* far
    - Hey
- Going back again

Here is another:

- An item
    - Going out 
        - Going out **more**
            - This is the limit

Here is a nested ordered list:

1. Here is something
    a. Here is another thing
        i. *Another!*
        5. The actual char used doesn't do anything (don't tell anyone!)
    b. And back again

And here is a mix:

1. Hey
    a. What is up
    b. This is cool
        i. Yeah sure
            - Okay
            - Mmm
    c. Sure
2. Cool
    - Why not

It's hard to come up with things to write in these tests
